<?php
e_include('ext_newsletter/class/motorNewsletter','ext_newsletter/class/listaNewsletter');

if (!class_exists("Mailchimp")){
	require_once(dirname(__FILE__) .'/mailchimp/Mailchimp.php');
}

/**
 * Eventos Api Adapter class for the Mideas Framework.
 *
 * @package		Mideas.Framework
 * @subpackage	Api
 * @since		1.0
 */
class MailchimpMotorNewsletter extends MotorNewsletter
{
	protected $id = 'Mailchimp';
	protected $apiKey = '';
	
	public function __construct($apiKey){
		parent::__construct();
		
		if (empty($apiKey) && $GLOBALS["opciones"]["ext_newsletter"]["general"]["motor"] == "Mailchimp")
			$apiKey = $GLOBALS["opciones"]["ext_newsletter"]["general"]["opcionesmotor"]["apiKey"];
		
		if (!empty($apiKey))
			$this->init_mc($apiKey);
	}
	
	private function init_mc($apiKey){
		if (!class_exists("Mailchimp")){
			require_once(dirname(__FILE__) .'/mailchimp/Mailchimp.php');
		}
		if (!class_exists("Mailchimp") || empty($apiKey)){
			return false;
		}
		
		$mc = new Mailchimp($apiKey);
		
		$this->objeto = $mc;
		
		return true;
	}
	
	public function getLista($id=null){
		if (empty($id))
			return false;
			
		if ($this->objeto instanceof Mailchimp){
			
			$lista = $this->objeto->lists->getList(array("list_id"=>$id));
			
			if ($lista["total"] == 1){
				$list = $lista["data"][0];
				
				$list_obj = new ListaNewsletter();
					
				$list_obj->id = $list["id"];
				$list_obj->nombre = json_encode(array(SistemaIdioma::getIdiomaSesion()=>$list["name"]));
				$list_obj->alias = json_encode(array(SistemaIdioma::getIdiomaSesion()=>Helpers::parseaTexto($list["name"])));
				$list_obj->fecha = $list["date_created"];
				
				if ($list["visibility"] == "pub"){
					$list_obj->estado = 1;
				} else {
					$list_obj->estado = 0;
				}
				
				$list_obj->creador = 0;
				
				$list_obj->padre = 0;
				
				$list_obj->motor = "Mailchimp";
				
				$list_obj->params = json_encode($list);
				
				$list_obj->webid = $list["web_id"];
				
				$list_obj->custom_edit_url = CONF_URL_APP_ADMIN.'?extension=ext_newsletter&vista=editar_lista&motor=Mailchimp&cid='.$list["id"];
				
				$list_obj->num_suscriptores = $list["stats"]["member_count"];
				
				return $list_obj;
			} else {
				return false;
			}
		} else {
			return false;
		}
	}
	
	public function getListas($inicio=0, $limite=25, $orden='created', $orden_dir='DESC'){
		if ($this->objeto instanceof Mailchimp){
			$listas = $this->objeto->lists->getList(array(), $inicio, $limite, $orden, $orden_dir);
			
			$listas_parsed = array();
			
			if ((int) $listas["total"] > 0){
				foreach ($listas["data"] as $list){
					$list_obj = new ListaNewsletter();
					
					$list_obj->id = $list["id"];
					$list_obj->nombre = json_encode(array(SistemaIdioma::getIdiomaSesion()=>$list["name"]));
					$list_obj->alias = json_encode(array(SistemaIdioma::getIdiomaSesion()=>Helpers::parseaTexto($list["name"])));
					$list_obj->fecha = $list["date_created"];
					
					if ($list["visibility"] == "pub"){
						$list_obj->estado = 1;
					} else {
						$list_obj->estado = 0;
					}
					
					$list_obj->creador = 0;
					
					$list_obj->padre = 0;
					
					$list_obj->motor = "Mailchimp";
					
					$list_obj->params = json_encode($list);
					
					$list_obj->webid = $list["web_id"];
					
					$list_obj->custom_edit_url = CONF_URL_APP_ADMIN.'?extension=ext_newsletter&vista=editar_lista&motor=Mailchimp&cid='.$list["id"];
					
					$list_obj->num_suscriptores = $list["stats"]["member_count"];
					
					$listas_parsed[] = $list_obj;
				}
			}
			
			$this->listas["total"] = $listas["total"];
			$this->listas["data"] = $listas_parsed;
			
			return $this->listas;
		} else {
			return false;
		}
	}
	
	public function sendSubscribeForm($list_id, $email, $nombre){
		if (empty($list_id) || empty($email) || !is_object($this->objeto))
			return false;
			
		try {
			$suscribir_usuario_a_lista = $this->objeto->lists->subscribe($list_id, array("email"=>$email), null, 'html', true,  false,  true,  false);
		} catch(Exception $e){
			return array("tipo"=>"error", "msg"=>$e->getMessage());
		}
		
		return $suscribir_usuario_a_lista;
	}
	
	public function sendUnSubscribeForm($list_id, $email){
		if (empty($list_id) || empty($email) || !is_object($this->objeto))
			return false;
			
		try {
			$desuscribir_usuario_de_lista = $this->objeto->lists->unsubscribe($list_id, array("email"=>$email), false, true, true);
		} catch(Exception $e){
			return array("tipo"=>"error", "msg"=>$e->getMessage());
		}
		
		return $desuscribir_usuario_de_lista;
	}
	
	function opciones_admin($name_input, $valores=array()){
		if (empty($name_input)){
			$name_input = "mailchimp_motornewsletter";
		}
		
		$output = '<div class="row">';
		
		$output .= '<div class="col-xs-6">';
		$output .= '<div class="input-group"><label>'.__('Api Key').'</label></div>';
		$output .= '<div class="controls"><input type="text" class="form-control" name="'.$name_input.'[apiKey]" value="'.$valores["apiKey"].'" /></div>';
		$output .= '</div>';
		
		$output .= '<div class="col-xs-6">';
		$output .= '<div class="input-group"><label>'.__('URL del panel de administración').'</label></div>';
		$output .= '<div class="controls"><input type="text" class="form-control" name="'.$name_input.'[urladmin]" value="'.$valores["urladmin"].'" /></div>';
		$output .= '</div>';
		
		$output .= '</div>';
		
		return $output;
	}
	
	function getAdminListOpts($val, $attr){
		$listas = $this->getListas(0,100,"list_name","ASC");
		
		$opts = array();

		if ($listas["total"] > 0){
			foreach ($listas["data"] as $list){
				$sel_txt = '';
				if ($list->id == $val){
					$sel_txt = ' selected="selected"';
				}
				$opts[] = '<option value="'.$list->id.'"'.$sel_txt.'>'.SistemaIdioma::Imprimir($list->nombre).' (Mailchimp)</option>';
			}
		}

		return implode("", $opts);
	}
}